@@ -1,15 +1,15 @@
 """Adapter implementations for various ticket systems."""
 
 from .aitrackdown import AITrackdownAdapter
-from .linear import LinearAdapter
-from .jira import JiraAdapter
 from .github import GitHubAdapter
 from .hybrid import HybridAdapter
+from .jira import JiraAdapter
+from .linear import LinearAdapter
 
 __all__ = [
     "AITrackdownAdapter",
     "LinearAdapter",
     "JiraAdapter",
     "GitHubAdapter",
-    "HybridAdapter"
-]
\ No newline at end of file
+    "HybridAdapter",
+]
