@@ -1,7 +1,6 @@
 """GitHub adapter implementation using REST API v3 and GraphQL API v4."""
 
 import builtins
-import os
 import re
 from datetime import datetime
 from typing import Any, Optional
@@ -9,6 +8,7 @@ from typing import Any, Optional
 import httpx
 
 from ..core.adapter import BaseAdapter
+from ..core.env_loader import load_adapter_config, validate_adapter_config
 from ..core.models import Comment, Epic, Priority, SearchQuery, Task, TicketState
 from ..core.registry import AdapterRegistry
 
@@ -151,21 +151,26 @@ class GitHubAdapter(BaseAdapter[Task]):
         """
         super().__init__(config)
 
-        # Get authentication token - support both 'api_key' and 'token' for compatibility
-        self.token = (
-            config.get("api_key") or config.get("token") or os.getenv("GITHUB_TOKEN")
-        )
-        if not self.token:
+        # Load configuration with environment variable resolution
+        full_config = load_adapter_config("github", config)
+
+        # Validate required configuration
+        missing_keys = validate_adapter_config("github", full_config)
+        if missing_keys:
             raise ValueError(
-                "GitHub token required (config.api_key, config.token or GITHUB_TOKEN env var)"
+                f"GitHub adapter missing required configuration: {', '.join(missing_keys)}"
             )
 
-        # Get repository information
-        self.owner = config.get("owner") or os.getenv("GITHUB_OWNER")
-        self.repo = config.get("repo") or os.getenv("GITHUB_REPO")
+        # Get authentication token - support both 'api_key' and 'token' for compatibility
+        self.token = (
+            full_config.get("api_key")
+            or full_config.get("token")
+            or full_config.get("token")
+        )
 
-        if not self.owner or not self.repo:
-            raise ValueError("GitHub owner and repo are required")
+        # Get repository information
+        self.owner = full_config.get("owner")
+        self.repo = full_config.get("repo")
 
         # API URLs
         self.api_url = config.get("api_url", "https://api.github.com")
@@ -598,7 +603,7 @@ class GitHubAdapter(BaseAdapter[Task]):
             labels_to_update = update_data.get("labels", current_labels)
             all_priority_labels = []
             for labels in GitHubStateMapping.PRIORITY_LABELS.values():
-                all_priority_labels.extend([l.lower() for l in labels])
+                all_priority_labels.extend([label.lower() for label in labels])
 
             labels_to_update = [
                 label
@@ -1329,6 +1334,20 @@ Fixes #{issue_number}
             "message": f"Successfully linked PR #{pr_number} to issue #{issue_number}",
         }
 
+    async def get_collaborators(self) -> builtins.list[dict[str, Any]]:
+        """Get repository collaborators."""
+        response = await self.client.get(
+            f"/repos/{self.owner}/{self.repo}/collaborators"
+        )
+        response.raise_for_status()
+        return response.json()
+
+    async def get_current_user(self) -> Optional[dict[str, Any]]:
+        """Get current authenticated user information."""
+        response = await self.client.get("/user")
+        response.raise_for_status()
+        return response.json()
+
     async def close(self) -> None:
         """Close the HTTP client connection."""
         await self.client.aclose()
