@@ -12,18 +12,19 @@ from dotenv import load_dotenv
 from rich.console import Console
 from rich.table import Table
 
-from ..__version__ import __version__
-from ..core import AdapterRegistry, Priority, TicketState
-from ..core.models import SearchQuery
-from ..queue import Queue, QueueStatus, WorkerManager
-from ..queue.health_monitor import QueueHealthMonitor, HealthStatus
-from ..queue.ticket_registry import TicketRegistry
-
 # Import adapters module to trigger registration
 import mcp_ticketer.adapters  # noqa: F401
+
+from ..__version__ import __version__
+from ..core import AdapterRegistry, Priority, TicketState
+from ..core.models import Comment, SearchQuery
+from ..queue import Queue, QueueStatus, WorkerManager
+from ..queue.health_monitor import HealthStatus, QueueHealthMonitor
+from ..queue.ticket_registry import TicketRegistry
 from .configure import configure_wizard, set_adapter_config, show_current_config
 from .diagnostics import run_diagnostics
 from .discover import app as discover_app
+from .linear_commands import app as linear_app
 from .migrate_config import migrate_config_command
 from .queue_commands import app as queue_app
 
@@ -149,8 +150,8 @@ def _discover_from_env_files() -> Optional[str]:
 
     Returns:
         Adapter name if discovered, None otherwise
+
     """
-    import os
     import logging
     from pathlib import Path
 
@@ -165,12 +166,12 @@ def _discover_from_env_files() -> Optional[str]:
             try:
                 # Simple .env parsing (key=value format)
                 env_vars = {}
-                with open(env_path, 'r') as f:
+                with open(env_path) as f:
                     for line in f:
                         line = line.strip()
-                        if line and not line.startswith('#') and '=' in line:
-                            key, value = line.split('=', 1)
-                            env_vars[key.strip()] = value.strip().strip('"\'')
+                        if line and not line.startswith("#") and "=" in line:
+                            key, value = line.split("=", 1)
+                            env_vars[key.strip()] = value.strip().strip("\"'")
 
                 # Check for adapter-specific variables
                 if env_vars.get("LINEAR_API_KEY"):
@@ -194,6 +195,7 @@ def _save_adapter_to_config(adapter_name: str) -> None:
 
     Args:
         adapter_name: Name of the adapter to save as default
+
     """
     import logging
 
@@ -316,13 +318,163 @@ def get_adapter(
     return AdapterRegistry.get_adapter(adapter_type, adapter_config)
 
 
+def _prompt_for_adapter_selection(console: Console) -> str:
+    """Interactive prompt for adapter selection.
+
+    Args:
+        console: Rich console for output
+
+    Returns:
+        Selected adapter type
+
+    """
+    console.print("\n[bold blue]🚀 MCP Ticketer Setup[/bold blue]")
+    console.print("Choose which ticket system you want to connect to:\n")
+
+    # Define adapter options with descriptions
+    adapters = [
+        {
+            "name": "linear",
+            "title": "Linear",
+            "description": "Modern project management (linear.app)",
+            "requirements": "API key and team ID",
+        },
+        {
+            "name": "github",
+            "title": "GitHub Issues",
+            "description": "GitHub repository issues",
+            "requirements": "Personal access token, owner, and repo",
+        },
+        {
+            "name": "jira",
+            "title": "JIRA",
+            "description": "Atlassian JIRA project management",
+            "requirements": "Server URL, email, and API token",
+        },
+        {
+            "name": "aitrackdown",
+            "title": "Local Files (AITrackdown)",
+            "description": "Store tickets in local files (no external service)",
+            "requirements": "None - works offline",
+        },
+    ]
+
+    # Display options
+    for i, adapter in enumerate(adapters, 1):
+        console.print(f"[cyan]{i}.[/cyan] [bold]{adapter['title']}[/bold]")
+        console.print(f"   {adapter['description']}")
+        console.print(f"   [dim]Requirements: {adapter['requirements']}[/dim]\n")
+
+    # Get user selection
+    while True:
+        try:
+            choice = typer.prompt("Select adapter (1-4)", type=int, default=1)
+            if 1 <= choice <= len(adapters):
+                selected_adapter = adapters[choice - 1]
+                console.print(
+                    f"\n[green]✓ Selected: {selected_adapter['title']}[/green]"
+                )
+                return selected_adapter["name"]
+            else:
+                console.print(
+                    f"[red]Please enter a number between 1 and {len(adapters)}[/red]"
+                )
+        except (ValueError, typer.Abort):
+            console.print("[yellow]Setup cancelled.[/yellow]")
+            raise typer.Exit(0)
+
+
+@app.command()
+def setup(
+    adapter: Optional[str] = typer.Option(
+        None,
+        "--adapter",
+        "-a",
+        help="Adapter type to use (interactive prompt if not specified)",
+    ),
+    project_path: Optional[str] = typer.Option(
+        None, "--path", help="Project path (default: current directory)"
+    ),
+    global_config: bool = typer.Option(
+        False,
+        "--global",
+        "-g",
+        help="Save to global config instead of project-specific",
+    ),
+    base_path: Optional[str] = typer.Option(
+        None,
+        "--base-path",
+        "-p",
+        help="Base path for ticket storage (AITrackdown only)",
+    ),
+    api_key: Optional[str] = typer.Option(
+        None, "--api-key", help="API key for Linear or API token for JIRA"
+    ),
+    team_id: Optional[str] = typer.Option(
+        None, "--team-id", help="Linear team ID (required for Linear adapter)"
+    ),
+    jira_server: Optional[str] = typer.Option(
+        None,
+        "--jira-server",
+        help="JIRA server URL (e.g., https://company.atlassian.net)",
+    ),
+    jira_email: Optional[str] = typer.Option(
+        None, "--jira-email", help="JIRA user email for authentication"
+    ),
+    jira_project: Optional[str] = typer.Option(
+        None, "--jira-project", help="Default JIRA project key"
+    ),
+    github_owner: Optional[str] = typer.Option(
+        None, "--github-owner", help="GitHub repository owner"
+    ),
+    github_repo: Optional[str] = typer.Option(
+        None, "--github-repo", help="GitHub repository name"
+    ),
+    github_token: Optional[str] = typer.Option(
+        None, "--github-token", help="GitHub Personal Access Token"
+    ),
+) -> None:
+    """Interactive setup wizard for MCP Ticketer (alias for init).
+
+    This command provides a user-friendly setup experience with prompts
+    to guide you through configuring MCP Ticketer for your preferred
+    ticket management system. It's identical to 'init' and 'install'.
+
+    Examples:
+        # Run interactive setup
+        mcp-ticketer setup
+
+        # Setup with specific adapter
+        mcp-ticketer setup --adapter linear
+
+        # Setup for different project
+        mcp-ticketer setup --path /path/to/project
+
+    """
+    # Call init with all parameters
+    init(
+        adapter=adapter,
+        project_path=project_path,
+        global_config=global_config,
+        base_path=base_path,
+        api_key=api_key,
+        team_id=team_id,
+        jira_server=jira_server,
+        jira_email=jira_email,
+        jira_project=jira_project,
+        github_owner=github_owner,
+        github_repo=github_repo,
+        github_token=github_token,
+    )
+
+
 @app.command()
 def init(
     adapter: Optional[str] = typer.Option(
         None,
         "--adapter",
         "-a",
-        help="Adapter type to use (auto-detected from .env if not specified)",
+        help="Adapter type to use (interactive prompt if not specified)",
     ),
     project_path: Optional[str] = typer.Option(
         None, "--path", help="Project path (default: current directory)"
@@ -368,11 +520,17 @@ def init(
 ) -> None:
     """Initialize mcp-ticketer for the current project.
 
+    This command sets up MCP Ticketer configuration with interactive prompts
+    to guide you through the process. It auto-detects adapter configuration
+    from .env files or prompts for interactive setup if no configuration is found.
+
     Creates .mcp-ticketer/config.json in the current directory with
     auto-detected or specified adapter configuration.
 
+    Note: 'setup' and 'install' are synonyms for this command.
+
     Examples:
-        # Auto-detect from .env.local
+        # Interactive setup (same as 'setup' and 'install')
         mcp-ticketer init
 
         # Force specific adapter
@@ -413,32 +571,61 @@ def init(
         console.print(
             "[cyan]🔍 Auto-discovering configuration from .env files...[/cyan]"
         )
-        discovered = discover_config(proj_path)
 
-        if discovered and discovered.adapters:
-            primary = discovered.get_primary_adapter()
-            if primary:
-                adapter_type = primary.adapter_type
-                console.print(
-                    f"[green]✓ Detected {adapter_type} adapter from environment files[/green]"
-                )
+        # First try our improved .env configuration loader
+        from ..mcp.server import _load_env_configuration
 
-                # Show what was discovered
-                console.print(
-                    f"\n[dim]Configuration found in: {primary.found_in}[/dim]"
-                )
-                console.print(f"[dim]Confidence: {primary.confidence:.0%}[/dim]")
-            else:
-                adapter_type = "aitrackdown"  # Fallback
-                console.print(
-                    "[yellow]⚠ No credentials found, defaulting to aitrackdown[/yellow]"
-                )
-        else:
-            adapter_type = "aitrackdown"  # Fallback
+        env_config = _load_env_configuration()
+
+        if env_config:
+            adapter_type = env_config["adapter_type"]
             console.print(
-                "[yellow]⚠ No .env files found, defaulting to aitrackdown[/yellow]"
+                f"[green]✓ Detected {adapter_type} adapter from environment files[/green]"
             )
 
+            # Show what was discovered
+            console.print("\n[dim]Configuration found in: .env files[/dim]")
+            console.print("[dim]Confidence: 100%[/dim]")
+
+            # Ask user to confirm auto-detected adapter
+            if not typer.confirm(
+                f"Use detected {adapter_type} adapter?",
+                default=True,
+            ):
+                adapter_type = None  # Will trigger interactive selection
+        else:
+            # Fallback to old discovery system for backward compatibility
+            discovered = discover_config(proj_path)
+
+            if discovered and discovered.adapters:
+                primary = discovered.get_primary_adapter()
+                if primary:
+                    adapter_type = primary.adapter_type
+                    console.print(
+                        f"[green]✓ Detected {adapter_type} adapter from environment files[/green]"
+                    )
+
+                    # Show what was discovered
+                    console.print(
+                        f"\n[dim]Configuration found in: {primary.found_in}[/dim]"
+                    )
+                    console.print(f"[dim]Confidence: {primary.confidence:.0%}[/dim]")
+
+                    # Ask user to confirm auto-detected adapter
+                    if not typer.confirm(
+                        f"Use detected {adapter_type} adapter?",
+                        default=True,
+                    ):
+                        adapter_type = None  # Will trigger interactive selection
+                else:
+                    adapter_type = None  # Will trigger interactive selection
+            else:
+                adapter_type = None  # Will trigger interactive selection
+
+        # If no adapter determined, show interactive selection
+        if not adapter_type:
+            adapter_type = _prompt_for_adapter_selection(console)
+
     # 2. Create configuration based on adapter type
     config = {"default_adapter": adapter_type, "adapters": {}}
 
@@ -457,63 +644,107 @@ def init(
     if adapter_type == "aitrackdown":
         config["adapters"]["aitrackdown"] = {
             "type": "aitrackdown",
-            "base_path": base_path or ".aitrackdown"
+            "base_path": base_path or ".aitrackdown",
         }
 
     elif adapter_type == "linear":
-        # If not auto-discovered, build from CLI params
+        # If not auto-discovered, build from CLI params or prompt
         if adapter_type not in config["adapters"]:
             linear_config = {}
 
-            # Team ID
-            if team_id:
-                linear_config["team_id"] = team_id
-
             # API Key
             linear_api_key = api_key or os.getenv("LINEAR_API_KEY")
-            if linear_api_key:
-                linear_config["api_key"] = linear_api_key
-            elif not discovered:
-                console.print("[yellow]Warning:[/yellow] No Linear API key provided.")
+            if not linear_api_key and not discovered:
+                console.print("\n[bold]Linear Configuration[/bold]")
+                console.print("You need a Linear API key to connect to Linear.")
                 console.print(
-                    "Set LINEAR_API_KEY environment variable or use --api-key option"
+                    "[dim]Get your API key at: https://linear.app/settings/api[/dim]\n"
                 )
 
-            if linear_config:
-                linear_config["type"] = "linear"
-                config["adapters"]["linear"] = linear_config
+                linear_api_key = typer.prompt(
+                    "Enter your Linear API key", hide_input=True
+                )
+
+            if linear_api_key:
+                linear_config["api_key"] = linear_api_key
+
+            # Team ID
+            linear_team_id = team_id or os.getenv("LINEAR_TEAM_ID")
+            if not linear_team_id and not discovered:
+                console.print("\nYou need your Linear team ID.")
+                console.print("[dim]Find it in Linear settings or team URL[/dim]\n")
+
+                linear_team_id = typer.prompt("Enter your Linear team ID")
+
+            if linear_team_id:
+                linear_config["team_id"] = linear_team_id
+
+            if not linear_config.get("api_key") or not linear_config.get("team_id"):
+                console.print(
+                    "[red]Error:[/red] Linear requires both API key and team ID"
+                )
+                console.print(
+                    "Run 'mcp-ticketer init --adapter linear' with proper credentials"
+                )
+                raise typer.Exit(1)
+
+            linear_config["type"] = "linear"
+            config["adapters"]["linear"] = linear_config
 
     elif adapter_type == "jira":
-        # If not auto-discovered, build from CLI params
+        # If not auto-discovered, build from CLI params or prompt
         if adapter_type not in config["adapters"]:
             server = jira_server or os.getenv("JIRA_SERVER")
             email = jira_email or os.getenv("JIRA_EMAIL")
             token = api_key or os.getenv("JIRA_API_TOKEN")
             project = jira_project or os.getenv("JIRA_PROJECT_KEY")
 
+            # Interactive prompts for missing values
+            if not server and not discovered:
+                console.print("\n[bold]JIRA Configuration[/bold]")
+                console.print("Enter your JIRA server details.\n")
+
+                server = typer.prompt(
+                    "JIRA server URL (e.g., https://company.atlassian.net)"
+                )
+
+            if not email and not discovered:
+                email = typer.prompt("Your JIRA email address")
+
+            if not token and not discovered:
+                console.print("\nYou need a JIRA API token.")
+                console.print(
+                    "[dim]Generate one at: https://id.atlassian.com/manage/api-tokens[/dim]\n"
+                )
+
+                token = typer.prompt("Enter your JIRA API token", hide_input=True)
+
+            if not project and not discovered:
+                project = typer.prompt(
+                    "Default JIRA project key (optional, press Enter to skip)",
+                    default="",
+                    show_default=False,
+                )
+
+            # Validate required fields
             if not server:
                 console.print("[red]Error:[/red] JIRA server URL is required")
-                console.print(
-                    "Use --jira-server or set JIRA_SERVER environment variable"
-                )
                 raise typer.Exit(1)
 
             if not email:
                 console.print("[red]Error:[/red] JIRA email is required")
-                console.print("Use --jira-email or set JIRA_EMAIL environment variable")
                 raise typer.Exit(1)
 
             if not token:
                 console.print("[red]Error:[/red] JIRA API token is required")
-                console.print(
-                    "Use --api-key or set JIRA_API_TOKEN environment variable"
-                )
-                console.print(
-                    "[dim]Generate token at: https://id.atlassian.com/manage/api-tokens[/dim]"
-                )
                 raise typer.Exit(1)
 
-            jira_config = {"server": server, "email": email, "api_token": token}
+            jira_config = {
+                "server": server,
+                "email": email,
+                "api_token": token,
+                "type": "jira",
+            }
 
             if project:
                 jira_config["project_key"] = project
@@ -521,45 +752,57 @@ def init(
             config["adapters"]["jira"] = jira_config
 
     elif adapter_type == "github":
-        # If not auto-discovered, build from CLI params
+        # If not auto-discovered, build from CLI params or prompt
         if adapter_type not in config["adapters"]:
             owner = github_owner or os.getenv("GITHUB_OWNER")
             repo = github_repo or os.getenv("GITHUB_REPO")
             token = github_token or os.getenv("GITHUB_TOKEN")
 
+            # Interactive prompts for missing values
+            if not owner and not discovered:
+                console.print("\n[bold]GitHub Configuration[/bold]")
+                console.print("Enter your GitHub repository details.\n")
+
+                owner = typer.prompt(
+                    "GitHub repository owner (username or organization)"
+                )
+
+            if not repo and not discovered:
+                repo = typer.prompt("GitHub repository name")
+
+            if not token and not discovered:
+                console.print("\nYou need a GitHub Personal Access Token.")
+                console.print(
+                    "[dim]Create one at: https://github.com/settings/tokens/new[/dim]"
+                )
+                console.print(
+                    "[dim]Required scopes: repo (for private repos) or public_repo (for public repos)[/dim]\n"
+                )
+
+                token = typer.prompt(
+                    "Enter your GitHub Personal Access Token", hide_input=True
+                )
+
+            # Validate required fields
             if not owner:
                 console.print("[red]Error:[/red] GitHub repository owner is required")
-                console.print(
-                    "Use --github-owner or set GITHUB_OWNER environment variable"
-                )
                 raise typer.Exit(1)
 
             if not repo:
                 console.print("[red]Error:[/red] GitHub repository name is required")
-                console.print(
-                    "Use --github-repo or set GITHUB_REPO environment variable"
-                )
                 raise typer.Exit(1)
 
             if not token:
                 console.print(
                     "[red]Error:[/red] GitHub Personal Access Token is required"
                 )
-                console.print(
-                    "Use --github-token or set GITHUB_TOKEN environment variable"
-                )
-                console.print(
-                    "[dim]Create token at: https://github.com/settings/tokens/new[/dim]"
-                )
-                console.print(
-                    "[dim]Required scopes: repo (for private repos) or public_repo (for public repos)[/dim]"
-                )
                 raise typer.Exit(1)
 
             config["adapters"]["github"] = {
                 "owner": owner,
                 "repo": repo,
                 "token": token,
+                "type": "github",
             }
 
     # 5. Save to appropriate location
@@ -599,6 +842,53 @@ def init(
                 f.write("# MCP Ticketer\n.mcp-ticketer/\n")
             console.print("[dim]✓ Created .gitignore with .mcp-ticketer/[/dim]")
 
+    # Show next steps
+    _show_next_steps(console, adapter_type, config_file_path)
+
+
+def _show_next_steps(
+    console: Console, adapter_type: str, config_file_path: Path
+) -> None:
+    """Show helpful next steps after initialization.
+
+    Args:
+        console: Rich console for output
+        adapter_type: Type of adapter that was configured
+        config_file_path: Path to the configuration file
+
+    """
+    console.print("\n[bold green]🎉 Setup Complete![/bold green]")
+    console.print(f"MCP Ticketer is now configured to use {adapter_type.title()}.\n")
+
+    console.print("[bold]Next Steps:[/bold]")
+    console.print("1. [cyan]Test your configuration:[/cyan]")
+    console.print("   mcp-ticketer diagnose")
+    console.print("\n2. [cyan]Create a test ticket:[/cyan]")
+    console.print("   mcp-ticketer create 'Test ticket from MCP Ticketer'")
+
+    if adapter_type != "aitrackdown":
+        console.print(
+            f"\n3. [cyan]Verify the ticket appears in {adapter_type.title()}[/cyan]"
+        )
+
+        if adapter_type == "linear":
+            console.print("   Check your Linear workspace for the new ticket")
+        elif adapter_type == "github":
+            console.print("   Check your GitHub repository's Issues tab")
+        elif adapter_type == "jira":
+            console.print("   Check your JIRA project for the new ticket")
+    else:
+        console.print("\n3. [cyan]Check local ticket storage:[/cyan]")
+        console.print("   ls .aitrackdown/")
+
+    console.print("\n4. [cyan]Configure MCP clients (optional):[/cyan]")
+    console.print("   mcp-ticketer mcp claude    # For Claude Code")
+    console.print("   mcp-ticketer mcp auggie    # For Auggie")
+    console.print("   mcp-ticketer mcp gemini    # For Gemini CLI")
+
+    console.print(f"\n[dim]Configuration saved to: {config_file_path}[/dim]")
+    console.print("[dim]Run 'mcp-ticketer --help' for more commands[/dim]")
+
 
 @app.command()
 def install(
@@ -652,12 +942,12 @@ def install(
 ) -> None:
     """Initialize mcp-ticketer for the current project (alias for init).
 
-    This command is synonymous with 'init' and provides the same functionality.
-    Creates .mcp-ticketer/config.json in the current directory with
-    auto-detected or specified adapter configuration.
+    This command is synonymous with 'init' and 'setup' - all three provide
+    identical functionality with interactive prompts to guide you through
+    configuring MCP Ticketer for your preferred ticket management system.
 
     Examples:
-        # Auto-detect from .env.local
+        # Interactive setup (same as 'init' and 'setup')
         mcp-ticketer install
 
         # Force specific adapter
@@ -885,11 +1175,14 @@ def status_command():
 
 @app.command()
 def health(
-    auto_repair: bool = typer.Option(False, "--auto-repair", help="Attempt automatic repair of issues"),
-    verbose: bool = typer.Option(False, "--verbose", "-v", help="Show detailed health information")
+    auto_repair: bool = typer.Option(
+        False, "--auto-repair", help="Attempt automatic repair of issues"
+    ),
+    verbose: bool = typer.Option(
+        False, "--verbose", "-v", help="Show detailed health information"
+    ),
 ) -> None:
     """Check queue system health and detect issues immediately."""
-
     health_monitor = QueueHealthMonitor()
     health = health_monitor.check_health()
 
@@ -898,14 +1191,14 @@ def health(
         HealthStatus.HEALTHY: "green",
         HealthStatus.WARNING: "yellow",
         HealthStatus.CRITICAL: "red",
-        HealthStatus.FAILED: "red"
+        HealthStatus.FAILED: "red",
     }
 
     status_icon = {
         HealthStatus.HEALTHY: "✓",
         HealthStatus.WARNING: "⚠️",
         HealthStatus.CRITICAL: "🚨",
-        HealthStatus.FAILED: "❌"
+        HealthStatus.FAILED: "❌",
     }
 
     color = status_color.get(health["status"], "white")
@@ -928,7 +1221,10 @@ def health(
         console.print("\n[green]✓ No issues detected[/green]")
 
     # Auto-repair if requested
-    if auto_repair and health["status"] in [HealthStatus.CRITICAL, HealthStatus.WARNING]:
+    if auto_repair and health["status"] in [
+        HealthStatus.CRITICAL,
+        HealthStatus.WARNING,
+    ]:
         console.print("\n[yellow]Attempting automatic repair...[/yellow]")
         repair_result = health_monitor.auto_repair()
 
@@ -942,7 +1238,9 @@ def health(
             new_health = health_monitor.check_health()
             new_color = status_color.get(new_health["status"], "white")
             new_icon = status_icon.get(new_health["status"], "?")
-            console.print(f"[{new_color}]{new_icon} Updated Health: {new_health['status'].upper()}[/{new_color}]")
+            console.print(
+                f"[{new_color}]{new_icon} Updated Health: {new_health['status'].upper()}[/{new_color}]"
+            )
         else:
             console.print("[yellow]No repair actions available[/yellow]")
 
@@ -973,7 +1271,6 @@ def create(
     ),
 ) -> None:
     """Create a new ticket with comprehensive health checks."""
-
     # IMMEDIATE HEALTH CHECK - Critical for reliability
     health_monitor = QueueHealthMonitor()
     health = health_monitor.check_health()
@@ -996,13 +1293,21 @@ def create(
             # Re-check health after repair
             health = health_monitor.check_health()
             if health["status"] == HealthStatus.CRITICAL:
-                console.print("[red]❌ Auto-repair failed. Manual intervention required.[/red]")
-                console.print("[red]Cannot safely create ticket. Please check system status.[/red]")
+                console.print(
+                    "[red]❌ Auto-repair failed. Manual intervention required.[/red]"
+                )
+                console.print(
+                    "[red]Cannot safely create ticket. Please check system status.[/red]"
+                )
                 raise typer.Exit(1)
             else:
-                console.print("[green]✓ Auto-repair successful. Proceeding with ticket creation.[/green]")
+                console.print(
+                    "[green]✓ Auto-repair successful. Proceeding with ticket creation.[/green]"
+                )
         else:
-            console.print("[red]❌ No repair actions available. Manual intervention required.[/red]")
+            console.print(
+                "[red]❌ No repair actions available. Manual intervention required.[/red]"
+            )
             raise typer.Exit(1)
 
     elif health["status"] == HealthStatus.WARNING:
@@ -1033,23 +1338,84 @@ def create(
                 adapter_name = "aitrackdown"
 
     # Create task data
+    # Import Priority for type checking
+    from ..core.models import Priority as PriorityEnum
+
     task_data = {
         "title": title,
         "description": description,
-        "priority": priority.value if isinstance(priority, Priority) else priority,
+        "priority": priority.value if isinstance(priority, PriorityEnum) else priority,
         "tags": tags or [],
         "assignee": assignee,
     }
 
-    # Add to queue
+    # WORKAROUND: Use direct operation for Linear adapter to bypass worker subprocess issue
+    if adapter_name == "linear":
+        console.print(
+            "[yellow]⚠️[/yellow]  Using direct operation for Linear adapter (bypassing queue)"
+        )
+        try:
+            # Load configuration and create adapter directly
+            config = load_config()
+            adapter_config = config.get("adapters", {}).get(adapter_name, {})
+
+            # Import and create adapter
+            from ..core.registry import AdapterRegistry
+
+            adapter = AdapterRegistry.get_adapter(adapter_name, adapter_config)
+
+            # Create task directly
+            from ..core.models import Priority, Task
+
+            task = Task(
+                title=task_data["title"],
+                description=task_data.get("description"),
+                priority=(
+                    Priority(task_data["priority"])
+                    if task_data.get("priority")
+                    else Priority.MEDIUM
+                ),
+                tags=task_data.get("tags", []),
+                assignee=task_data.get("assignee"),
+            )
+
+            # Create ticket synchronously
+            import asyncio
+
+            result = asyncio.run(adapter.create(task))
+
+            console.print(f"[green]✓[/green] Ticket created successfully: {result.id}")
+            console.print(f"  Title: {result.title}")
+            console.print(f"  Priority: {result.priority}")
+            console.print(f"  State: {result.state}")
+            # Get URL from metadata if available
+            if (
+                result.metadata
+                and "linear" in result.metadata
+                and "url" in result.metadata["linear"]
+            ):
+                console.print(f"  URL: {result.metadata['linear']['url']}")
+
+            return result.id
+
+        except Exception as e:
+            console.print(f"[red]❌[/red] Failed to create ticket: {e}")
+            raise
+
+    # Use queue for other adapters
     queue = Queue()
     queue_id = queue.add(
-        ticket_data=task_data, adapter=adapter_name, operation="create"
+        ticket_data=task_data,
+        adapter=adapter_name,
+        operation="create",
+        project_dir=str(Path.cwd()),  # Explicitly pass current project directory
     )
 
     # Register in ticket registry for tracking
     registry = TicketRegistry()
-    registry.register_ticket_operation(queue_id, adapter_name, "create", title, task_data)
+    registry.register_ticket_operation(
+        queue_id, adapter_name, "create", title, task_data
+    )
 
     console.print(f"[green]✓[/green] Queued ticket creation: {queue_id}")
     console.print(f"  Title: {title}")
@@ -1066,6 +1432,7 @@ def create(
 
         # Give immediate feedback on processing
         import time
+
         time.sleep(1)  # Brief pause to let worker start
 
         # Check if item is being processed
@@ -1075,15 +1442,23 @@ def create(
         elif item and item.status == QueueStatus.PENDING:
             console.print("[yellow]⏳ Item is queued for processing[/yellow]")
         else:
-            console.print("[red]⚠️  Item status unclear - check with 'mcp-ticketer check {queue_id}'[/red]")
+            console.print(
+                "[red]⚠️  Item status unclear - check with 'mcp-ticketer check {queue_id}'[/red]"
+            )
     else:
         # Worker didn't start - this is a problem
         pending_count = queue.get_pending_count()
         if pending_count > 1:  # More than just this item
-            console.print(f"[red]❌ Worker failed to start with {pending_count} pending items![/red]")
-            console.print("[red]This is a critical issue. Try 'mcp-ticketer queue worker start' manually.[/red]")
+            console.print(
+                f"[red]❌ Worker failed to start with {pending_count} pending items![/red]"
+            )
+            console.print(
+                "[red]This is a critical issue. Try 'mcp-ticketer queue worker start' manually.[/red]"
+            )
         else:
-            console.print("[yellow]Worker not started (no other pending items)[/yellow]")
+            console.print(
+                "[yellow]Worker not started (no other pending items)[/yellow]"
+            )
 
 
 @app.command("list")
@@ -1127,12 +1502,15 @@ def list_tickets(
     table.add_column("Assignee", style="blue")
 
     for ticket in tickets:
+        # Handle assignee field - Epic doesn't have assignee, Task does
+        assignee = getattr(ticket, "assignee", None) or "-"
+
         table.add_row(
             ticket.id or "N/A",
             ticket.title,
             ticket.state,
             ticket.priority,
-            ticket.assignee or "-",
+            assignee,
         )
 
     console.print(table)
@@ -1188,6 +1566,42 @@ def show(
             console.print(comment.content)
 
 
+@app.command()
+def comment(
+    ticket_id: str = typer.Argument(..., help="Ticket ID"),
+    content: str = typer.Argument(..., help="Comment content"),
+    adapter: Optional[AdapterType] = typer.Option(
+        None, "--adapter", help="Override default adapter"
+    ),
+) -> None:
+    """Add a comment to a ticket."""
+
+    async def _comment():
+        adapter_instance = get_adapter(
+            override_adapter=adapter.value if adapter else None
+        )
+
+        # Create comment
+        comment = Comment(
+            ticket_id=ticket_id,
+            content=content,
+            author="cli-user",  # Could be made configurable
+        )
+
+        result = await adapter_instance.add_comment(comment)
+        return result
+
+    try:
+        result = asyncio.run(_comment())
+        console.print("[green]✓[/green] Comment added successfully")
+        if result.id:
+            console.print(f"Comment ID: {result.id}")
+        console.print(f"Content: {content}")
+    except Exception as e:
+        console.print(f"[red]✗[/red] Failed to add comment: {e}")
+        raise typer.Exit(1)
+
+
 @app.command()
 def update(
     ticket_id: str = typer.Argument(..., help="Ticket ID"),
@@ -1231,9 +1645,14 @@ def update(
     # Add ticket_id to updates
     updates["ticket_id"] = ticket_id
 
-    # Add to queue
+    # Add to queue with explicit project directory
     queue = Queue()
-    queue_id = queue.add(ticket_data=updates, adapter=adapter_name, operation="update")
+    queue_id = queue.add(
+        ticket_data=updates,
+        adapter=adapter_name,
+        operation="update",
+        project_dir=str(Path.cwd()),  # Explicitly pass current project directory
+    )
 
     console.print(f"[green]✓[/green] Queued ticket update: {queue_id}")
     for key, value in updates.items():
@@ -1289,7 +1708,7 @@ def transition(
         adapter.value if adapter else config.get("default_adapter", "aitrackdown")
     )
 
-    # Add to queue
+    # Add to queue with explicit project directory
     queue = Queue()
     queue_id = queue.add(
         ticket_data={
@@ -1300,6 +1719,7 @@ def transition(
         },
         adapter=adapter_name,
         operation="transition",
+        project_dir=str(Path.cwd()),  # Explicitly pass current project directory
     )
 
     console.print(f"[green]✓[/green] Queued state transition: {queue_id}")
@@ -1361,30 +1781,42 @@ app.add_typer(queue_app, name="queue")
 # Add discover command to main app
 app.add_typer(discover_app, name="discover")
 
+
 # Add diagnostics command
 @app.command()
 def diagnose(
-    output_file: Optional[str] = typer.Option(None, "--output", "-o", help="Save full report to file"),
-    json_output: bool = typer.Option(False, "--json", help="Output report in JSON format"),
-    simple: bool = typer.Option(False, "--simple", help="Use simple diagnostics (no heavy dependencies)"),
+    output_file: Optional[str] = typer.Option(
+        None, "--output", "-o", help="Save full report to file"
+    ),
+    json_output: bool = typer.Option(
+        False, "--json", help="Output report in JSON format"
+    ),
+    simple: bool = typer.Option(
+        False, "--simple", help="Use simple diagnostics (no heavy dependencies)"
+    ),
 ) -> None:
     """Run comprehensive system diagnostics and health check."""
     if simple:
         from .simple_health import simple_diagnose
+
         report = simple_diagnose()
         if output_file:
             import json
-            with open(output_file, 'w') as f:
+
+            with open(output_file, "w") as f:
                 json.dump(report, f, indent=2)
             console.print(f"\n📄 Report saved to: {output_file}")
         if json_output:
             import json
+
             console.print("\n" + json.dumps(report, indent=2))
         if report["issues"]:
             raise typer.Exit(1)
     else:
         try:
-            asyncio.run(run_diagnostics(output_file=output_file, json_output=json_output))
+            asyncio.run(
+                run_diagnostics(output_file=output_file, json_output=json_output)
+            )
         except typer.Exit:
             # typer.Exit is expected - don't fall back to simple diagnostics
             raise
@@ -1392,6 +1824,7 @@ def diagnose(
             console.print(f"⚠️  Full diagnostics failed: {e}")
             console.print("🔄 Falling back to simple diagnostics...")
             from .simple_health import simple_diagnose
+
             report = simple_diagnose()
             if report["issues"]:
                 raise typer.Exit(1)
@@ -1406,6 +1839,7 @@ def health() -> None:
     if result != 0:
         raise typer.Exit(result)
 
+
 # Create MCP configuration command group
 mcp_app = typer.Typer(
     name="mcp",
@@ -1483,16 +1917,28 @@ def serve(
     # Load configuration (respects project-specific config in cwd)
     config = load_config()
 
-    # Determine adapter type
-    adapter_type = (
-        adapter.value if adapter else config.get("default_adapter", "aitrackdown")
-    )
+    # Determine adapter type with priority: CLI arg > .env files > config > default
+    if adapter:
+        # Priority 1: Command line argument
+        adapter_type = adapter.value
+        # Get base config from config file
+        adapters_config = config.get("adapters", {})
+        adapter_config = adapters_config.get(adapter_type, {})
+    else:
+        # Priority 2: .env files
+        from ..mcp.server import _load_env_configuration
 
-    # Get adapter configuration
-    adapters_config = config.get("adapters", {})
-    adapter_config = adapters_config.get(adapter_type, {})
+        env_config = _load_env_configuration()
+        if env_config:
+            adapter_type = env_config["adapter_type"]
+            adapter_config = env_config["adapter_config"]
+        else:
+            # Priority 3: Configuration file
+            adapter_type = config.get("default_adapter", "aitrackdown")
+            adapters_config = config.get("adapters", {})
+            adapter_config = adapters_config.get(adapter_type, {})
 
-    # Override with command line options if provided
+    # Override with command line options if provided (highest priority)
     if base_path and adapter_type == "aitrackdown":
         adapter_config["base_path"] = base_path
 
@@ -1679,7 +2125,8 @@ def mcp_auggie(
         raise typer.Exit(1)
 
 
-# Add MCP command group to main app (must be after all subcommands are defined)
+# Add command groups to main app (must be after all subcommands are defined)
+app.add_typer(linear_app, name="linear")
 app.add_typer(mcp_app, name="mcp")
 
 
