@@ -1,8 +1,10 @@
 """Base adapter abstract class for ticket systems."""
 
+import builtins
 from abc import ABC, abstractmethod
-from typing import List, Optional, Dict, Any, TypeVar, Generic, Union
-from .models import Epic, Task, Comment, SearchQuery, TicketState, TicketType
+from typing import Any, Generic, Optional, TypeVar
+
+from .models import Comment, Epic, SearchQuery, Task, TicketState, TicketType
 
 # Generic type for tickets
 T = TypeVar("T", Epic, Task)
@@ -11,21 +13,23 @@ T = TypeVar("T", Epic, Task)
 class BaseAdapter(ABC, Generic[T]):
     """Abstract base class for all ticket system adapters."""
 
-    def __init__(self, config: Dict[str, Any]):
+    def __init__(self, config: dict[str, Any]):
         """Initialize adapter with configuration.
 
         Args:
             config: Adapter-specific configuration dictionary
+
         """
         self.config = config
         self._state_mapping = self._get_state_mapping()
 
     @abstractmethod
-    def _get_state_mapping(self) -> Dict[TicketState, str]:
+    def _get_state_mapping(self) -> dict[TicketState, str]:
         """Get mapping from universal states to system-specific states.
 
         Returns:
             Dictionary mapping TicketState to system-specific state strings
+
         """
         pass
 
@@ -35,6 +39,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             (is_valid, error_message) - Tuple of validation result and error message
+
         """
         pass
 
@@ -47,6 +52,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Created ticket with ID populated
+
         """
         pass
 
@@ -59,11 +65,12 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Ticket if found, None otherwise
+
         """
         pass
 
     @abstractmethod
-    async def update(self, ticket_id: str, updates: Dict[str, Any]) -> Optional[T]:
+    async def update(self, ticket_id: str, updates: dict[str, Any]) -> Optional[T]:
         """Update a ticket.
 
         Args:
@@ -72,6 +79,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Updated ticket if successful, None otherwise
+
         """
         pass
 
@@ -84,16 +92,14 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             True if deleted, False otherwise
+
         """
         pass
 
     @abstractmethod
     async def list(
-        self,
-        limit: int = 10,
-        offset: int = 0,
-        filters: Optional[Dict[str, Any]] = None
-    ) -> List[T]:
+        self, limit: int = 10, offset: int = 0, filters: Optional[dict[str, Any]] = None
+    ) -> list[T]:
         """List tickets with pagination and filters.
 
         Args:
@@ -103,11 +109,12 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of tickets matching criteria
+
         """
         pass
 
     @abstractmethod
-    async def search(self, query: SearchQuery) -> List[T]:
+    async def search(self, query: SearchQuery) -> builtins.list[T]:
         """Search tickets using advanced query.
 
         Args:
@@ -115,14 +122,13 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of tickets matching search criteria
+
         """
         pass
 
     @abstractmethod
     async def transition_state(
-        self,
-        ticket_id: str,
-        target_state: TicketState
+        self, ticket_id: str, target_state: TicketState
     ) -> Optional[T]:
         """Transition ticket to a new state.
 
@@ -132,6 +138,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Updated ticket if transition successful, None otherwise
+
         """
         pass
 
@@ -144,16 +151,14 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Created comment with ID populated
+
         """
         pass
 
     @abstractmethod
     async def get_comments(
-        self,
-        ticket_id: str,
-        limit: int = 10,
-        offset: int = 0
-    ) -> List[Comment]:
+        self, ticket_id: str, limit: int = 10, offset: int = 0
+    ) -> builtins.list[Comment]:
         """Get comments for a ticket.
 
         Args:
@@ -163,6 +168,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of comments for the ticket
+
         """
         pass
 
@@ -174,6 +180,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             System-specific state string
+
         """
         return self._state_mapping.get(state, state.value)
 
@@ -185,14 +192,13 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Universal ticket state
+
         """
         reverse_mapping = {v: k for k, v in self._state_mapping.items()}
         return reverse_mapping.get(system_state, TicketState.OPEN)
 
     async def validate_transition(
-        self,
-        ticket_id: str,
-        target_state: TicketState
+        self, ticket_id: str, target_state: TicketState
     ) -> bool:
         """Validate if state transition is allowed.
 
@@ -202,6 +208,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             True if transition is valid
+
         """
         ticket = await self.read(ticket_id)
         if not ticket:
@@ -218,10 +225,7 @@ class BaseAdapter(ABC, Generic[T]):
     # Epic/Issue/Task Hierarchy Methods
 
     async def create_epic(
-        self,
-        title: str,
-        description: Optional[str] = None,
-        **kwargs
+        self, title: str, description: Optional[str] = None, **kwargs
     ) -> Optional[Epic]:
         """Create epic (top-level grouping).
 
@@ -232,12 +236,13 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Created epic or None if failed
+
         """
         epic = Epic(
             title=title,
             description=description,
             ticket_type=TicketType.EPIC,
-            **{k: v for k, v in kwargs.items() if k in Epic.__fields__}
+            **{k: v for k, v in kwargs.items() if k in Epic.__fields__},
         )
         result = await self.create(epic)
         if isinstance(result, Epic):
@@ -252,6 +257,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Epic if found, None otherwise
+
         """
         # Default implementation - subclasses should override for platform-specific logic
         result = await self.read(epic_id)
@@ -259,7 +265,7 @@ class BaseAdapter(ABC, Generic[T]):
             return result
         return None
 
-    async def list_epics(self, **kwargs) -> List[Epic]:
+    async def list_epics(self, **kwargs) -> builtins.list[Epic]:
         """List all epics.
 
         Args:
@@ -267,6 +273,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of epics
+
         """
         # Default implementation - subclasses should override
         filters = kwargs.copy()
@@ -279,7 +286,7 @@ class BaseAdapter(ABC, Generic[T]):
         title: str,
         description: Optional[str] = None,
         epic_id: Optional[str] = None,
-        **kwargs
+        **kwargs,
     ) -> Optional[Task]:
         """Create issue, optionally linked to epic.
 
@@ -291,17 +298,18 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             Created issue or None if failed
+
         """
         task = Task(
             title=title,
             description=description,
             ticket_type=TicketType.ISSUE,
             parent_epic=epic_id,
-            **{k: v for k, v in kwargs.items() if k in Task.__fields__}
+            **{k: v for k, v in kwargs.items() if k in Task.__fields__},
         )
         return await self.create(task)
 
-    async def list_issues_by_epic(self, epic_id: str) -> List[Task]:
+    async def list_issues_by_epic(self, epic_id: str) -> builtins.list[Task]:
         """List all issues in epic.
 
         Args:
@@ -309,6 +317,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of issues belonging to epic
+
         """
         # Default implementation - subclasses should override for efficiency
         filters = {"parent_epic": epic_id, "ticket_type": TicketType.ISSUE}
@@ -316,11 +325,7 @@ class BaseAdapter(ABC, Generic[T]):
         return [r for r in results if isinstance(r, Task) and r.is_issue()]
 
     async def create_task(
-        self,
-        title: str,
-        parent_id: str,
-        description: Optional[str] = None,
-        **kwargs
+        self, title: str, parent_id: str, description: Optional[str] = None, **kwargs
     ) -> Optional[Task]:
         """Create task as sub-ticket of parent issue.
 
@@ -335,6 +340,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Raises:
             ValueError: If parent_id is not provided
+
         """
         if not parent_id:
             raise ValueError("Tasks must have a parent_id (issue)")
@@ -344,7 +350,7 @@ class BaseAdapter(ABC, Generic[T]):
             description=description,
             ticket_type=TicketType.TASK,
             parent_issue=parent_id,
-            **{k: v for k, v in kwargs.items() if k in Task.__fields__}
+            **{k: v for k, v in kwargs.items() if k in Task.__fields__},
         )
 
         # Validate hierarchy before creating
@@ -354,7 +360,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         return await self.create(task)
 
-    async def list_tasks_by_issue(self, issue_id: str) -> List[Task]:
+    async def list_tasks_by_issue(self, issue_id: str) -> builtins.list[Task]:
         """List all tasks under an issue.
 
         Args:
@@ -362,6 +368,7 @@ class BaseAdapter(ABC, Generic[T]):
 
         Returns:
             List of tasks belonging to issue
+
         """
         # Default implementation - subclasses should override for efficiency
         filters = {"parent_issue": issue_id, "ticket_type": TicketType.TASK}
@@ -370,4 +377,4 @@ class BaseAdapter(ABC, Generic[T]):
 
     async def close(self) -> None:
         """Close adapter and cleanup resources."""
-        pass
\ No newline at end of file
+        pass
