@@ -81,12 +81,22 @@ class WorkerManager:
         # Try to start worker
         return self.start()
 
-    def start(self) -> bool:
+    def start(self, timeout: float = 30.0) -> bool:
         """Start the worker process.
 
+        Args:
+            timeout: Maximum seconds to wait for worker to become fully operational (default: 30)
+
         Returns:
             True if started successfully, False otherwise
 
+        Raises:
+            TimeoutError: If worker doesn't start within timeout period
+
+        Note:
+            If timeout occurs, a worker may already be running in another process.
+            Check for stale lock files or processes using `get_status()`.
+
         """
         # Check if already running
         if self.is_running():
@@ -96,11 +106,41 @@ class WorkerManager:
         # Try to acquire lock
         if not self._acquire_lock():
             logger.warning("Could not acquire lock - another worker may be running")
-            return False
+            # Wait briefly to see if worker becomes operational
+            start_time = time.time()
+            while time.time() - start_time < timeout:
+                if self.is_running():
+                    logger.info("Worker started by another process")
+                    return True
+                time.sleep(1)
+
+            raise TimeoutError(
+                f"Worker start timed out after {timeout}s. "
+                f"Lock is held but worker is not running. "
+                f"Check for stale lock files or zombie processes."
+            )
 
         try:
-            # Start worker in subprocess
-            cmd = [sys.executable, "-m", "mcp_ticketer.queue.run_worker"]
+            # Start worker in subprocess using the same Python executable as the CLI
+            # This ensures the worker can import mcp_ticketer modules
+            python_executable = self._get_python_executable()
+            cmd = [python_executable, "-m", "mcp_ticketer.queue.run_worker"]
+
+            # Prepare environment for subprocess
+            # Ensure the subprocess gets the same environment as the parent
+            subprocess_env = os.environ.copy()
+
+            # Explicitly load environment variables from .env.local if it exists
+            env_file = Path.cwd() / ".env.local"
+            if env_file.exists():
+                logger.debug(f"Loading environment from {env_file} for subprocess")
+                from dotenv import dotenv_values
+
+                env_vars = dotenv_values(env_file)
+                subprocess_env.update(env_vars)
+                logger.debug(
+                    f"Added {len(env_vars)} environment variables from .env.local"
+                )
 
             # Start as background process
             process = subprocess.Popen(
@@ -108,25 +148,49 @@ class WorkerManager:
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL,
                 start_new_session=True,
+                env=subprocess_env,  # Pass environment explicitly
+                cwd=str(Path.cwd()),  # Ensure correct working directory
             )
 
             # Save PID
             self.pid_file.write_text(str(process.pid))
 
-            # Give the process a moment to start
-            import time
+            # Wait for worker to become fully operational with timeout
+            start_time = time.time()
+            while time.time() - start_time < timeout:
+                # Check if process exists
+                if not psutil.pid_exists(process.pid):
+                    logger.error("Worker process died during startup")
+                    self._cleanup()
+                    return False
 
-            time.sleep(0.5)
+                # Check if worker is fully running (not just process exists)
+                if self.is_running():
+                    elapsed = time.time() - start_time
+                    logger.info(
+                        f"Worker started successfully in {elapsed:.1f}s with PID {process.pid}"
+                    )
+                    return True
 
-            # Verify process is running
-            if not psutil.pid_exists(process.pid):
-                logger.error("Worker process died immediately after starting")
-                self._cleanup()
-                return False
+                # Log progress for long startups
+                elapsed = time.time() - start_time
+                if elapsed > 5 and int(elapsed) % 5 == 0:
+                    logger.debug(
+                        f"Waiting for worker to start, elapsed: {elapsed:.1f}s"
+                    )
 
-            logger.info(f"Started worker process with PID {process.pid}")
-            return True
+                time.sleep(0.5)
 
+            # Timeout reached
+            raise TimeoutError(
+                f"Worker start timed out after {timeout}s. "
+                f"Process spawned (PID {process.pid}) but worker did not become operational. "
+                f"Check worker logs for startup errors."
+            )
+
+        except TimeoutError:
+            # Re-raise timeout errors with context preserved
+            raise
         except Exception as e:
             logger.error(f"Failed to start worker: {e}")
             self._release_lock()
@@ -256,6 +320,48 @@ class WorkerManager:
         except (OSError, ValueError):
             return None
 
+    def _get_python_executable(self) -> str:
+        """Get the correct Python executable for the worker subprocess.
+
+        This ensures the worker uses the same Python environment as the CLI,
+        which is critical for module imports to work correctly.
+
+        Returns:
+            Path to Python executable
+
+        """
+        # First, try to detect if we're running in a pipx environment
+        # by checking if the current executable is in a pipx venv
+        current_executable = sys.executable
+
+        # Check if we're in a pipx venv (path contains /pipx/venvs/)
+        if "/pipx/venvs/" in current_executable:
+            logger.debug(f"Using pipx Python executable: {current_executable}")
+            return current_executable
+
+        # Check if we can find the mcp-ticketer executable and extract its Python
+        import shutil
+
+        mcp_ticketer_path = shutil.which("mcp-ticketer")
+        if mcp_ticketer_path:
+            try:
+                # Read the shebang line to get the Python executable
+                with open(mcp_ticketer_path) as f:
+                    first_line = f.readline().strip()
+                    if first_line.startswith("#!") and "python" in first_line:
+                        python_path = first_line[2:].strip()
+                        if os.path.exists(python_path):
+                            logger.debug(
+                                f"Using Python from mcp-ticketer shebang: {python_path}"
+                            )
+                            return python_path
+            except OSError:
+                pass
+
+        # Fallback to sys.executable
+        logger.debug(f"Using sys.executable as fallback: {current_executable}")
+        return current_executable
+
     def _cleanup(self):
         """Clean up lock and PID files."""
         self._release_lock()
